@@ -227,7 +227,7 @@ class CortxJupyter(ContentsManager):
             return (yield _delete_checkpoint(self._context(), checkpoint_id, path))
 
     def _context(self):
-        return Context(
+        return Context(s
             logger=self.log,
             region=self.aws_region,
             s3_bucket=self.aws_s3_bucket,
@@ -307,7 +307,7 @@ def _file_exists(context, path):
     @gen.coroutine
     def key_exists():
         key = _key(context, path)
-        response = yield _head_object(context.aws_s3_bucket, key)
+        response = yield _head_object(context.s3_bucket, key)
 
         return response
 
@@ -347,7 +347,7 @@ def _get_file_text(context, path, content):
 def _get_any(context, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
     key = _key(context, path)
-    response = yield _get_object(context.aws_s3_bucket, key)
+    response = yield _get_object(context.s3_bucket, key)
 
     file_bytes = response.Body
     last_modified_str = response.LastModified
@@ -467,7 +467,7 @@ def _save_chunk(context, chunk, content_bytes, path, type, mimetype):
 @gen.coroutine
 def _save_bytes(context, content_bytes, path, type, mimetype):
     object_name = _key(context, path)
-    _put_object(context.aws_s3_bucket, content_bytes, object_name)
+    _put_object(context.s3_bucket, content_bytes, object_name)
 
     last_modified_str = response.headers['Date']
     last_modified = datetime.datetime.strptime(
@@ -596,7 +596,7 @@ def _rename(context, old_path, new_path):
 
 @gen.coroutine
 def _copy_key(context, old_key, new_key):
-    yield _copy_object(context.aws_s3_bucket, f'/{context.s3_bucket}/{old_key}', new_key)
+    yield _copy_object(context.s3_bucket, f'/{context.s3_bucket}/{old_key}', new_key)
 
 
 @gen.coroutine
@@ -622,7 +622,7 @@ def _delete(context, path):
 
 @gen.coroutine
 def _delete_key(context, key):
-    yield _delete_object(context.aws_s3_bucket, key)
+    yield _delete_object(context.s3_bucket, key)
 
 
 @gen.coroutine
@@ -714,21 +714,22 @@ def _list_all_descendant_keys(context, key_prefix):
 
 
 @gen.coroutine
-def _list_keys(context, key_prefix, delimeter):
+def _list_keys(context, key_prefix, delimiter):
 
     max_keys = '1000'
 
     @gen.coroutine
     def _list_first_page():
 
-        response = yield _list_objects(context.aws_s3_bucket, key_prefix, delimiter, max_keys)
+        response = yield _list_objects(context.s3_bucket, key_prefix, delimiter, max_keys)
+
 
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
 
-        response = yield _list_objects(context.aws_s3_bucket, key_prefix, delimiter, max_keys, token)
+        response = yield _list_objects(context.s3_bucket, key_prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
